%maxwellboltzmann
% Function which generates a PNG plot of example Maxwell-Boltzmann particle
% speed distributions for various temperatures.
%
% LAST UPDATED by Andy French July 2016

function maxwellboltzmann

%Fontsize
fsize = 18;

%Temperatures in Kelvin
T = [300,500,700,1000];

%Boltzmann's constant /m^2 kg s^-2 K^-1
kB = 1.381e-23;

%Avogadro's number (particles per mol)
N_A = 6.0221409e23;

%Particle mass/kg
m = 28.97e-3;    %Air molecule)
m = m/N_A;

%Define RMS speeds /ms^-1
v_rms = sqrt( 3*kB*T/m );

%Define velocity limits
vmin = 0;
vmax = 2*max(v_rms);

%Number of plot evaluation points
N = 1000;

%%

%Generate vector of velocities
v = linspace( vmin, vmax, N );

%Generate PDF for Maxwell-Boltzmann speed distribution
p = zeros( N, numel(T) );
for n=1:numel(T)
    p(:,n) = 4*pi*( ( m/(2*pi*kB*T(n) ) )^(3/2) )*( v(:).^2 ).*....
        exp( (-0.5*m*v(:).^2)/(kB*T(n)) );
end

%Create Temperature legend cell array
for n=1:numel(T)
    legend_str{n} = ['T = ',num2str(T(n)),'K'];
end

%Plot distribution
v = repmat(v.',[1,numel(T)]);
plot(v,p);
xlim([vmin,vmax])
grid on;
set(gca,'fontsize',fsize)
xlabel('Speed /ms^{-1}','fontsize',fsize)
ylabel('Probability density','fontsize',fsize)
title('Maxwell-Boltzmann speed distribution','fontsize',fsize)
legend( legend_str,'fontsize',fsize );
print( gcf,'maxwell-boltzmann.png','-dpng','-r300' )
close(gcf);

%End of code